@@ -14,13 +14,14 @@ from ladybug_geometry.geometry2d.pointvector import Point2D
 from ladybug_geometry.geometry3d.face import Face3D
 from ladybug_geometry.geometry3d.pointvector import Vector3D, Point3D
 from ladybug_geometry.geometry3d.plane import Plane
+from ladybug_geometry.geometry3d.polyface import Polyface3D
 from ladybug.futil import preparedir
 from ladybug.location import Location
 from honeybee.typing import float_positive, invalid_dict_error
 from honeybee.checkdup import check_duplicate_identifiers
 from honeybee.units import conversion_factor_to_meters, UNITS, UNITS_TOLERANCES
 from honeybee.config import folders
-from honeybee.room import Room
+from honeybee.facetype import Floor, RoofCeiling
 from honeybee.model import Model as HBModel
 
 from ._base import _BaseGeometry
@@ -644,6 +645,7 @@ class Model(_BaseGeometry):
         msgs.append(self.check_duplicate_room_2d_identifiers(False, detailed))
         msgs.append(self.check_duplicate_story_identifiers(False, detailed))
         msgs.append(self.check_duplicate_building_identifiers(False, detailed))
+        msgs.append(self.check_window_parameters_valid(False, detailed))
         msgs.append(self.check_missing_adjacencies(False, detailed))
         # check the extension attributes
         ext_msgs = self._properties._check_extension_attr()
@@ -724,6 +726,36 @@ class Model(_BaseGeometry):
             self._context_shades, raise_exception, 'ContextShade', detailed,
             '100001', 'Core', 'Duplicate ContextShade Identifier')
 
+    def check_window_parameters_valid(self, raise_exception=True, detailed=False):
+        """Check that all Room2Ds have window parameters produce valid apertures.
+
+        This means that the resulting Apertures are completely bounded by their
+        parent wall Face.
+
+        Args:
+            raise_exception: Boolean to note whether a ValueError should be raised
+                if the window parameters are not valid.
+            detailed: Boolean for whether the returned object is a detailed list of
+                dicts with error info or a string with a message. (Default: False).
+
+        Returns:
+            A string with the message or a list with a dictionary if detailed is True.
+        """
+        detailed = False if raise_exception else detailed
+        msgs = []
+        for room in self.room_2ds:
+            msg = room.check_window_parameters_valid(False, detailed)
+            if detailed:
+                msgs.extend(msg)
+            elif msg != '':
+                msgs.append(msg)
+        if detailed:
+            return msgs
+        full_msg = '\n'.join(msgs)
+        if raise_exception and len(msgs) != 0:
+            raise ValueError(full_msg)
+        return full_msg
+
     def check_missing_adjacencies(self, raise_exception=True, detailed=False):
         """Check that all Room2Ds have adjacent objects that exist within each Story.
 
@@ -809,7 +841,9 @@ class Model(_BaseGeometry):
             enforce_adj: Boolean to note whether an exception should be raised if
                 an adjacency between two Room2Ds is invalid (True) or if the invalid
                 Surface boundary condition should be replaced with an Outdoor
-                boundary condition (False). (Default: True).
+                boundary condition (False). If False, any Walls containing
+                WindowParameters and an illegal boundary condition will also
+                be replaced with an Outdoor boundary condition. (Default: True).
 
         Returns:
             An array of Honeybee Models that together represent this Dragonfly Model.
@@ -849,7 +883,7 @@ class Model(_BaseGeometry):
         if solve_ceiling_adjacencies and \
                 object_per_model.title() in ('Building', 'District'):
             for model in models:
-                Room.solve_adjacency(model.rooms, tolerance)
+                self._solve_ceil_adj(model.rooms, tolerance)
 
         # change the tolerance and units systems to match the dragonfly model
         for model in models:
@@ -1032,7 +1066,7 @@ class Model(_BaseGeometry):
         Args:
             name: A text string for the name of the DFJSON file. If None, the model
                 identifier wil be used. (Default: None).
-            folder: A text string for the direcotry where the DFJSON will be written.
+            folder: A text string for the directory where the DFJSON will be written.
                 If unspecified, the default simulation folder will be used. This
                 is usually at "C:\\Users\\USERNAME\\simulation" on Windows.
             indent: A positive integer to set the indentation used in the resulting
@@ -1062,7 +1096,7 @@ class Model(_BaseGeometry):
         Args:
             name: A text string for the name of the pickle file. If None, the model
                 identifier wil be used. (Default: None).
-            folder: A text string for the direcotry where the pickle will be written.
+            folder: A text string for the directory where the pickle will be written.
                 If unspecified, the default simulation folder will be used. This
                 is usually at "C:\\Users\\USERNAME\\simulation."
             included_prop: List of properties to filter keys that must be included in
@@ -1092,6 +1126,27 @@ class Model(_BaseGeometry):
         """
         return writer
 
+    @staticmethod
+    def _solve_ceil_adj(rooms, tolerance=0.01):
+        """Solve Floor/Ceiling adjacencies between a list of rooms."""
+        relevant_types = (Floor, RoofCeiling)
+        # solve all adjacencies between rooms
+        for i, room_1 in enumerate(rooms):
+            try:
+                for room_2 in rooms[i + 1:]:
+                    if not Polyface3D.overlapping_bounding_boxes(
+                            room_1.geometry, room_2.geometry, tolerance):
+                        continue  # no overlap in bounding box; adjacency impossible
+                    for face_1 in room_1._faces:
+                        for face_2 in room_2._faces:
+                            if isinstance(face_2.type, relevant_types):
+                                if face_1.geometry.is_centered_adjacent(
+                                        face_2.geometry, tolerance):
+                                    face_1.set_adjacency(face_2)
+                                    break
+            except IndexError:
+                pass  # we have reached the end of the list of zones
+
     @staticmethod
     def _objects_from_geojson(bldgs_data, existing_to_context, scale_to_meters,
                               origin_lon_lat, convert_facs):
@@ -1125,7 +1180,7 @@ class Model(_BaseGeometry):
                         _geojson_coordinates, origin_lon_lat, convert_facs)
                     footprint.append(face3d)
 
-            # determine whether the footprint should be conext or a building
+            # determine whether the footprint should be context or a building
             if existing_to_context and 'building_status' in prop \
                     and prop['building_status'] == 'Existing':
                 ht = prop['maximum_roof_height'] * scale_to_meters \
